Crate duniter_rs_wotb

Crate duniter_rs_wotb 

duniter-rs-wotb is a crate making Web of Trust computations for the Duniter project.

It defines a structure storing a Web of Trust (WoT).

WoT test is translated from [duniter/wotb Javascript test] (https://github.com/duniter/wotb/blob/master/wotcpp/webOfTrust.cpp).

Larger WoT test is missing and will only be made in the Javascript wrapper of this module to be sure it’s fully compatible with the actual duniter-ts software.

Structs

NodeId
Wrapper for a node id.
WebOfTrust
Store a Web of Trust.
WotDistance
Results of WebOfTrust::compute_distance.

Enums

NewLinkResult
Results of a certification, with the current certification count of the destination as parameter.
RemovedLinkResult
Results of a certification removal, with the current certification count of the destination as parameter.